multidim.models.GaussianMixtureClassifier.plot — GDA Toolbox v1.0 Manual

# multidim.models.GaussianMixtureClassifier.plot

`GaussianMixtureClassifier.` `plot`(canvas, style='covertree')

  Plot a CDER model, using matplotlib or bokeh

  There are several options to help visualize various aspects of the model. Typically, one wants to overlay this with the plots from the underlying `multidim.PointCloud` and `multidim.covertree.CoverTree` objects.

  Parameters: | canvas : object An instance of `bokeh.plotting.figure.Figure` as in `canvas = bokeh.plotting.figure()` or an instance of `matplotlib.axes._subplots.AxesSubplot` as in `axes,canvas = matplotlib.pyplot.subplots()` style : str options are “gaussians”, “covertree”, “heatmap”, “hulls”, “expatriots”, and “predictions”. Colors are generally obtained from the label names.

  See also

  `multidim.PointCloud.plot()`, `multidim.covertree.CoverTree.plot()`

#### Previous topic

multidim.models.GaussianMixtureClassifier.get_params

#### Next topic

multidim.models.GaussianMixtureClassifier.predict